Stan Math Library: Namespace Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

- All
- Functions
- Variables
- Typedefs

- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w

Here is a list of all namespace members with links to the namespace documentation for each member:

### - n -

- neg_binomial_2_ccdf_log() : stan::math
- neg_binomial_2_cdf() : stan::math
- neg_binomial_2_cdf_log() : stan::math
- neg_binomial_2_log() : stan::math
- neg_binomial_2_log_log() : stan::math
- neg_binomial_2_log_rng() : stan::math
- neg_binomial_2_rng() : stan::math
- neg_binomial_ccdf_log() : stan::math
- neg_binomial_cdf() : stan::math
- neg_binomial_cdf_log() : stan::math
- neg_binomial_log() : stan::math
- neg_binomial_rng() : stan::math
- NEG_LOG_PI : stan::math
- NEG_LOG_SQRT_PI : stan::math
- NEG_LOG_SQRT_TWO_PI : stan::math
- NEG_LOG_TWO : stan::math
- NEG_LOG_TWO_OVER_TWO : stan::math
- NEG_LOG_TWO_PI : stan::math
- NEG_TWO_OVER_SQRT_PI : stan::math
- NEGATIVE_EPSILON : stan::math
- negative_infinity() : stan::math
- NEGATIVE_INFTY : stan::math
- nested_size() : stan::math
- normal_ccdf_log() : stan::math
- normal_cdf() : stan::math
- normal_cdf_log() : stan::math
- normal_log() : stan::math
- normal_rng() : stan::math
- NOT_A_NUMBER : stan::math
- not_a_number() : stan::math
- num_elements() : stan::math

[ Stan Home Page ] © 2011–2016, Stan Development Team.